<!DOCTYPE html>
<html lang="en-us"> 
  <head>
  <meta charset="UTF-8">
  <title>Research Software Encyclopedia</title>
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/normalize/8.0.1/normalize.min.css">
  <link rel="stylesheet" href="//fonts.googleapis.com/css?family=Source+Sans+Pro:300,300i,600">
  <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/font-awesome/4.7.0/css/font-awesome.min.css">
  <link rel='stylesheet' href='https://use.fontawesome.com/releases/v5.0.6/css/all.css'>

</head>
{% block content %}{% endblock %}
<footer class="site-footer">
  <span class="site-footer-credits">Contribute to the Research Software Encyclopedia on <a target="_blank" href="https://github.com/rseng/software">GitHub</a>, the software for it at <a target="_blank" href="https://github.com/rseng/rse">rseng/rse</a>, or the community taxonomy and criteria at <a target="_blank" href="https://github.com/rseng/rseng">rseng/rseng</a>.</span>
</footer>

  </body>
</html>

